@@ -10,7 +10,7 @@ pub fn app() -> App<'static> {
             Arg::new("commit-message-path")
                 .about("The name of the file that contains the commit log message")
                 .index(1)
-                .required(true),
+                .required_unless_present("completion"),
         )
         .arg(
             Arg::new("commit-message-source")
@@ -46,4 +46,11 @@ pub fn app() -> App<'static> {
                 .takes_value(true)
                 .required(false),
         )
+        .arg(Arg::new("completion").long("completion").possible_values(&[
+            "bash",
+            "elvish",
+            "fish",
+            "powershell",
+            "zsh",
+        ]))
 }
