@@ -4,9 +4,6 @@ use thiserror::Error;
 #[derive(Error, Debug, Diagnostic)]
 pub(crate) enum MitPrepareCommitMessageError {
     #[error("Expected commit file path")]
-    #[diagnostic(
-        url(docsrs),
-        code(mit_prepare_commit_msg::errors::missing_commit_file_path)
-    )]
+    #[diagnostic(code(mit_prepare_commit_msg::errors::missing_commit_file_path))]
     MissingCommitFilePath,
 }
